use strict;
use warnings;
package Email::Sender::Manual 2.500;
# ABSTRACT: table of contents for the Email::Sender manual

#pod =head1 THE MANUAL
#pod
#pod L<Email::Sender::Manual::QuickStart> tells you just what you need to know to
#pod start using Email::Sender.
#pod
#pod =cut

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Email::Sender::Manual - table of contents for the Email::Sender manual

=head1 VERSION

version 2.500

=head1 PERL VERSION

This library should run on perls released even a long time ago.  It should work
on any version of perl released in the last five years.

Although it may work on older versions of perl, no guarantee is made that the
minimum required version will not be increased.  The version may be increased
for any reason, and there is no promise that patches will be accepted to lower
the minimum required perl.

=head1 THE MANUAL

L<Email::Sender::Manual::QuickStart> tells you just what you need to know to
start using Email::Sender.

=head1 AUTHOR

Ricardo Signes <rjbs@semiotic.systems>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by Ricardo Signes.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
